==> django_start_automate-1.0.3.tar.gz: django_start_automate-1.0.3/README.md <==
<h1 style="
text-align: center;
font-family: Serif;
font-size: 6vh;
">
<span style="
color: darkgoldenrod;
letter-spacing: -6px;
margin-right: -2.2%;"
>Django</span>
<span style="
color: darkgoldenrod;
letter-spacing: -3px;"
>Start</span>
Automate Script ✨
</h1>

<div style="
text-align: center;
background: rgba(131,131,131,0.17);
padding: 10px;
border-radius: 5px;
width: 650px;
margin: 0 auto
">
    Django automate start project and create app
    This script saves time for you to start a new Django project.
    It creates the project and creates the first app
    and then updates the project settings file and
    also updates the project urls file and then creates a views
    and configures the application urls file and
    also creates the index.html
</div>
<div style="text-align: center; margin-top: 10px">
<img src="https://img.shields.io/github/stars/islam-kamel/django-start?style=social" alt="Repo Stars">
<img src="https://img.shields.io/badge/platform-Windows%20%7C%20Linux-green" alt="Platform Support">
<img src="https://img.shields.io/badge/Latest%20Version-1.0.0--beta.2-green" alt="Latest Version">
<img src="https://img.shields.io/github/downloads/islam-kamel/django-start/total", alt="Downloads Count">
<img src="https://img.shields.io/github/release-date-pre/islam-kamel/django-start", alt="GitHub (Pre-)Release Date">
</div>

---
## Welcome to contribute ❤

```shell
pip install pyinstaller | pyinstaller --noconfirm --onefile --console --add-data <requests_package_path> --add-data <djstartlib>  "django-start.py"
```

==> django_start_automate-1.0.4.tar.gz: django_start_automate-1.0.4/README.md <==
<h1 style="
text-align: center;
font-family: Serif;
font-size: 6vh;
">
<span style="
color: darkgoldenrod;
letter-spacing: -6px;
margin-right: -2.2%;"
>Django</span>
<span style="
color: darkgoldenrod;
letter-spacing: -3px;"
>Start</span>
Automate Script ✨
</h1>

<div style="
text-align: center;
background: rgba(131,131,131,0.17);
padding: 10px;
border-radius: 5px;
width: 650px;
margin: 0 auto
">
    Django automate start project and create app
    This script saves time for you to start a new Django project.
    It creates the project and creates the first app
    and then updates the project settings file and
    also updates the project urls file and then creates a views
    and configures the application urls file and
    also creates the index.html
</div>
<div style="text-align: center; margin-top: 10px">
<img src="https://img.shields.io/github/stars/islam-kamel/django-start?style=social" alt="Repo Stars">
<img src="https://img.shields.io/badge/platform-Windows%20%7C%20Linux-green" alt="Platform Support">
<img src="https://img.shields.io/badge/Latest%20Version-1.0.0--beta.2-green" alt="Latest Version">
<img src="https://img.shields.io/github/downloads/islam-kamel/django-start/total", alt="Downloads Count">
<img src="https://img.shields.io/github/release-date-pre/islam-kamel/django-start", alt="GitHub (Pre-)Release Date">
</div>

---

### Installation

````shell
pip install django-start-automate
````

````shell
django-start --help

usage: django-start [-h] [-v] [-n ] project_name app_name path

django-start 1.0.4 (Beta) automate start project and create app

positional arguments:
  project_name      Write a project name
  app_name          Write an app name
  path              select path

options:
  -h, --help        show this help message and exit
  -v, --virtualenv  Create virtualenv
  -n [], --name []  Set virtualenv name

````
**Success Install 🎊**

### Start First Project with virtualenv
```shell
django-start frist_project first_app -v -n my_virtualenv .
```
---
> You can run command without create virrualenv
```shell
django-start frist_project first_app .
```

![img.png](assest/img.png)

## Welcome to contribute ❤
### [django-start](!https://github.com/islam-kamel/django-start) 🧑‍💻
